@@ -16,7 +16,6 @@ from datetime import datetime
 from typing import Any, Dict, List, Type
 
 from botocore.client import ClientMeta
-from botocore.exceptions import ClientError as Boto3ClientError
 
 from mypy_boto3_compute_optimizer.type_defs import (
     DescribeRecommendationExportJobsResponseTypeDef,
@@ -42,22 +41,30 @@ else:
 __all__ = ("ComputeOptimizerClient",)
 
 
+class BotocoreClientError(BaseException):
+    MSG_TEMPLATE: str
+
+    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
+        self.response: Dict[str, Any]
+        self.operation_name: str
+
+
 class Exceptions:
-    AccessDeniedException: Type[Boto3ClientError]
-    ClientError: Type[Boto3ClientError]
-    InternalServerException: Type[Boto3ClientError]
-    InvalidParameterValueException: Type[Boto3ClientError]
-    LimitExceededException: Type[Boto3ClientError]
-    MissingAuthenticationToken: Type[Boto3ClientError]
-    OptInRequiredException: Type[Boto3ClientError]
-    ResourceNotFoundException: Type[Boto3ClientError]
-    ServiceUnavailableException: Type[Boto3ClientError]
-    ThrottlingException: Type[Boto3ClientError]
+    AccessDeniedException: Type[BotocoreClientError]
+    ClientError: Type[BotocoreClientError]
+    InternalServerException: Type[BotocoreClientError]
+    InvalidParameterValueException: Type[BotocoreClientError]
+    LimitExceededException: Type[BotocoreClientError]
+    MissingAuthenticationToken: Type[BotocoreClientError]
+    OptInRequiredException: Type[BotocoreClientError]
+    ResourceNotFoundException: Type[BotocoreClientError]
+    ServiceUnavailableException: Type[BotocoreClientError]
+    ThrottlingException: Type[BotocoreClientError]
 
 
 class ComputeOptimizerClient:
     """
-    [ComputeOptimizer.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/compute-optimizer.html#ComputeOptimizer.Client)
+    [ComputeOptimizer.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/compute-optimizer.html#ComputeOptimizer.Client)
     """
 
     meta: ClientMeta
@@ -65,7 +72,7 @@ class ComputeOptimizerClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/compute-optimizer.html#ComputeOptimizer.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/compute-optimizer.html#ComputeOptimizer.Client.can_paginate)
         """
 
     def describe_recommendation_export_jobs(
@@ -76,7 +83,7 @@ class ComputeOptimizerClient:
         maxResults: int = None,
     ) -> DescribeRecommendationExportJobsResponseTypeDef:
         """
-        [Client.describe_recommendation_export_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/compute-optimizer.html#ComputeOptimizer.Client.describe_recommendation_export_jobs)
+        [Client.describe_recommendation_export_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/compute-optimizer.html#ComputeOptimizer.Client.describe_recommendation_export_jobs)
         """
 
     def export_auto_scaling_group_recommendations(
@@ -125,7 +132,7 @@ class ComputeOptimizerClient:
         includeMemberAccounts: bool = None,
     ) -> ExportAutoScalingGroupRecommendationsResponseTypeDef:
         """
-        [Client.export_auto_scaling_group_recommendations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/compute-optimizer.html#ComputeOptimizer.Client.export_auto_scaling_group_recommendations)
+        [Client.export_auto_scaling_group_recommendations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/compute-optimizer.html#ComputeOptimizer.Client.export_auto_scaling_group_recommendations)
         """
 
     def export_ec2_instance_recommendations(
@@ -170,7 +177,7 @@ class ComputeOptimizerClient:
         includeMemberAccounts: bool = None,
     ) -> ExportEC2InstanceRecommendationsResponseTypeDef:
         """
-        [Client.export_ec2_instance_recommendations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/compute-optimizer.html#ComputeOptimizer.Client.export_ec2_instance_recommendations)
+        [Client.export_ec2_instance_recommendations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/compute-optimizer.html#ComputeOptimizer.Client.export_ec2_instance_recommendations)
         """
 
     def generate_presigned_url(
@@ -181,7 +188,7 @@ class ComputeOptimizerClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/compute-optimizer.html#ComputeOptimizer.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/compute-optimizer.html#ComputeOptimizer.Client.generate_presigned_url)
         """
 
     def get_auto_scaling_group_recommendations(
@@ -193,7 +200,7 @@ class ComputeOptimizerClient:
         filters: List[FilterTypeDef] = None,
     ) -> GetAutoScalingGroupRecommendationsResponseTypeDef:
         """
-        [Client.get_auto_scaling_group_recommendations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_auto_scaling_group_recommendations)
+        [Client.get_auto_scaling_group_recommendations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_auto_scaling_group_recommendations)
         """
 
     def get_ec2_instance_recommendations(
@@ -205,7 +212,7 @@ class ComputeOptimizerClient:
         accountIds: List[str] = None,
     ) -> GetEC2InstanceRecommendationsResponseTypeDef:
         """
-        [Client.get_ec2_instance_recommendations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_ec2_instance_recommendations)
+        [Client.get_ec2_instance_recommendations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_ec2_instance_recommendations)
         """
 
     def get_ec2_recommendation_projected_metrics(
@@ -217,19 +224,19 @@ class ComputeOptimizerClient:
         endTime: datetime,
     ) -> GetEC2RecommendationProjectedMetricsResponseTypeDef:
         """
-        [Client.get_ec2_recommendation_projected_metrics documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_ec2_recommendation_projected_metrics)
+        [Client.get_ec2_recommendation_projected_metrics documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_ec2_recommendation_projected_metrics)
         """
 
     def get_enrollment_status(self) -> GetEnrollmentStatusResponseTypeDef:
         """
-        [Client.get_enrollment_status documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_enrollment_status)
+        [Client.get_enrollment_status documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_enrollment_status)
         """
 
     def get_recommendation_summaries(
         self, accountIds: List[str] = None, nextToken: str = None, maxResults: int = None
     ) -> GetRecommendationSummariesResponseTypeDef:
         """
-        [Client.get_recommendation_summaries documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_recommendation_summaries)
+        [Client.get_recommendation_summaries documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_recommendation_summaries)
         """
 
     def update_enrollment_status(
@@ -238,5 +245,5 @@ class ComputeOptimizerClient:
         includeMemberAccounts: bool = None,
     ) -> UpdateEnrollmentStatusResponseTypeDef:
         """
-        [Client.update_enrollment_status documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/compute-optimizer.html#ComputeOptimizer.Client.update_enrollment_status)
+        [Client.update_enrollment_status documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/compute-optimizer.html#ComputeOptimizer.Client.update_enrollment_status)
         """
